@@ -5,8 +5,8 @@ use crate::error::{Error, Result};
 use crate::game::GameTime;
 use crate::io::read::{Reader, MAX_SIZE};
 use crate::packet::Packet;
-use bytes::Bytes;
 use crossbeam::atomic::AtomicCell;
+use easy_pool::PoolObjectContainer;
 use std::convert::TryInto;
 use std::marker::PhantomData;
 use std::sync::{atomic::Ordering, Arc};
@@ -63,7 +63,7 @@ where
     fn handle_ping(&self, packet: Packet) -> Result<()> {
         if let Some(content) = packet.payload {
             self.world_session.socket_tools().send(0, Some(&content));
-            let latency = parse_ping(content)?;
+            let latency = parse_ping(&*content)?;
             self.world_session
                 .socket_tools()
                 .latency
@@ -125,7 +125,7 @@ where
         let mut reader = Reader::new(buffer);
         loop {
             let result = self
-                .process_packet(&mut reader, game_time, timeout_read, &world_session, world)
+                .process_packet(&mut reader, game_time, timeout_read, world_session, world)
                 .await;
 
             if result.is_err() {
@@ -215,7 +215,7 @@ where
                         continue;
                     }
 
-                    if writer.write_all(&data).await.is_err() {
+                    if writer.write_all(&data.bytes()).await.is_err() {
                         break;
                     }
 
@@ -246,7 +246,7 @@ where
     }
 }
 
-fn parse_ping(content: Vec<u8>) -> Result<i64> {
+fn parse_ping(content: &[u8]) -> Result<i64> {
     if content.len() == 16 {
         let middle = content.len() / 2;
         let latency = content[middle..]
@@ -259,13 +259,36 @@ fn parse_ping(content: Vec<u8>) -> Result<i64> {
     }
 }
 
+pub enum ContainerBytes {
+    Raw(PoolObjectContainer<Vec<u8>>),
+    Arc(Arc<PoolObjectContainer<Vec<u8>>>),
+}
+
+impl ContainerBytes {
+    pub fn bytes(&self) -> &[u8] {
+        match self {
+            ContainerBytes::Raw(b) => &*b,
+            ContainerBytes::Arc(b) => &*b,
+        }
+    }
+
+    pub fn is_empty(&self) -> bool {
+        match self {
+            ContainerBytes::Raw(b) => b.is_empty(),
+            ContainerBytes::Arc(b) => b.is_empty(),
+        }
+    }
+}
+
 pub(crate) enum WriterMessage {
     Close,
     Flush,
     CloseDelayed(Duration),
-    Send(Bytes, bool),
+    Send(ContainerBytes, bool),
     #[cfg(feature = "flatbuffers_helpers")]
-    SendFlatbuffers(Box<dyn Fn(&mut FlatBufferBuilder<'static>) -> Bytes + Send + Sync>),
+    SendFlatbuffers(
+        Box<dyn Fn(&mut FlatBufferBuilder<'static>) -> PoolObjectContainer<Vec<u8>> + Send + Sync>,
+    ),
 }
 
 #[cfg(test)]
@@ -282,6 +305,6 @@ mod tests {
         bytes.put_u16(100); // Ping Date
         bytes.put_i64(75); // Latency
 
-        assert_eq!(parse_ping(bytes.to_vec()).unwrap(), 75);
+        assert_eq!(parse_ping(&bytes.to_vec()).unwrap(), 75);
     }
 }
